<!--
&lt;--- Readme.md Snippet without images Start ---&gt;
## Tech Stack
erling6232/imagedata_format_biff is built on the following main stack:

- [Python](https://www.python.org) – Languages
- [pgvector](https://github.com/pgvector/pgvector/) – Database Tools
- [GitHub Actions](https://github.com/features/actions) – Continuous Integration
- [Travis CI](http://travis-ci.com/) – Continuous Integration
- [LangChain](https://github.com/hwchase17/langchain) – Large Language Model Tools

Full tech stack [here](/techstack.md)

&lt;--- Readme.md Snippet without images End ---&gt;

&lt;--- Readme.md Snippet with images Start ---&gt;
## Tech Stack
erling6232/imagedata_format_biff is built on the following main stack:

- <img width='25' height='25' src='https://img.stackshare.io/service/993/pUBY5pVj.png' alt='Python'/> [Python](https://www.python.org) – Languages
- <img width='25' height='25' src='https://img.stackshare.io/service/109221/default_b888cdf5617d936aa6aacf130911906955508639.png' alt='pgvector'/> [pgvector](https://github.com/pgvector/pgvector/) – Database Tools
- <img width='25' height='25' src='https://img.stackshare.io/service/11563/actions.png' alt='GitHub Actions'/> [GitHub Actions](https://github.com/features/actions) – Continuous Integration
- <img width='25' height='25' src='https://img.stackshare.io/service/460/Lu6cGu0z_400x400.png' alt='Travis CI'/> [Travis CI](http://travis-ci.com/) – Continuous Integration
- <img width='25' height='25' src='https://img.stackshare.io/service/48790/default_5b6c6b73f1ff3775c85d2a1ba954cb87e30cbf13.jpg' alt='LangChain'/> [LangChain](https://github.com/hwchase17/langchain) – Large Language Model Tools

Full tech stack [here](/techstack.md)

&lt;--- Readme.md Snippet with images End ---&gt;
-->
<div align="center">

# Tech Stack File
![](https://img.stackshare.io/repo.svg "repo") [erling6232/imagedata_format_biff](https://github.com/erling6232/imagedata_format_biff)![](https://img.stackshare.io/public_badge.svg "public")
<br/><br/>
|6<br/>Tools used|02/29/24 <br/>Report generated|
|------|------|
</div>

## <img src='https://img.stackshare.io/languages.svg'/> Languages (1)
<table><tr>
  <td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/993/pUBY5pVj.png' alt='Python'>
  <br>
  <sub><a href="https://www.python.org">Python</a></sub>
  <br>
  <sub></sub>
</td>

</tr>
</table>

## <img src='https://img.stackshare.io/databases.svg'/> Data (1)
<table><tr>
  <td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/109221/default_b888cdf5617d936aa6aacf130911906955508639.png' alt='pgvector'>
  <br>
  <sub><a href="https://github.com/pgvector/pgvector/">pgvector</a></sub>
  <br>
  <sub></sub>
</td>

</tr>
</table>

## <img src='https://img.stackshare.io/devops.svg'/> DevOps (3)
<table><tr>
  <td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/1046/git.png' alt='Git'>
  <br>
  <sub><a href="http://git-scm.com/">Git</a></sub>
  <br>
  <sub></sub>
</td>

<td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/11563/actions.png' alt='GitHub Actions'>
  <br>
  <sub><a href="https://github.com/features/actions">GitHub Actions</a></sub>
  <br>
  <sub></sub>
</td>

<td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/460/Lu6cGu0z_400x400.png' alt='Travis CI'>
  <br>
  <sub><a href="http://travis-ci.com/">Travis CI</a></sub>
  <br>
  <sub></sub>
</td>

</tr>
</table>

## Other (1)
<table><tr>
  <td align='center'>
  <img width='36' height='36' src='https://img.stackshare.io/service/48790/default_5b6c6b73f1ff3775c85d2a1ba954cb87e30cbf13.jpg' alt='LangChain'>
  <br>
  <sub><a href="https://github.com/hwchase17/langchain">LangChain</a></sub>
  <br>
  <sub></sub>
</td>

</tr>
</table>

<br/>
<div align='center'>

Generated via [Stack File](https://github.com/marketplace/stack-file)
